Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetActivity ¶
Types ¶
type Activity ¶
type Activity struct {
// What the player is currently doing
Details string
// The user's current party status
State string
// The id for a large asset of the activity, usually a snowflake
LargeImage string
// Text displayed when hovering over the large image of the activity
LargeText string
// The id for a small asset of the activity, usually a snowflake
SmallImage string
// Text displayed when hovering over the small image of the activity
SmallText string
// Information for the current party of the player
Party *Party
// Unix timestamps for start and/or end of the game
Timestamps *Timestamps
// Secrets for Rich Presence joining and spectating
Secrets *Secrets
}
Activity holds the data for discord rich presence
type Args ¶
type Args struct {
Pid int `json:"pid"`
Activity *PayloadActivity `json:"activity"`
}
type Party ¶
type Party struct {
// The ID of the party
ID string
// Used to show the party's current size
Players int
// Used to show the party's maximum size
MaxPlayers int
}
Party holds information for the current party of the player
type PayloadActivity ¶
type PayloadActivity struct {
Details string `json:"details"`
State string `json:"state"`
Assets PayloadAssets `json:"assets"`
Party *PayloadParty `json:"party,omitempty"`
Timestamps *PayloadTimestamps `json:"timestamps,omitempty"`
Secrets *PayloadSecrets `json:"secrets,omitempty"`
}
type PayloadAssets ¶
type PayloadParty ¶
type PayloadSecrets ¶
type PayloadTimestamps ¶
Click to show internal directories.
Click to hide internal directories.